#version 150

#moj_import <light.glsl>
#moj_import <fog.glsl>

in vec3 Position;
in vec4 Color;
in vec2 UV0;
in ivec2 UV1;
in ivec2 UV2;
in vec3 Normal;

uniform sampler2D Sampler1;
uniform sampler2D Sampler2;

uniform mat4 ModelViewMat;
uniform mat4 ProjMat;
uniform int FogShape;

uniform vec3 Light0_Direction;
uniform vec3 Light1_Direction;

out float vertexDistance;
out vec4 vertexColor;
out vec4 lightMapColor;
out vec4 overlayColor;
out vec2 texCoord0;

void main() {
    gl_Position = ProjMat * ModelViewMat * vec4(Position, 1.0);

    vertexDistance = fog_distance(Position, FogShape);
    if(Position.z-30 > 0.9){
        vertexColor = minecraft_mix_light(Light0_Direction, Light1_Direction, Normal, Color);
    }
    else if(Position.z-30 > 0.7){
        float resultcol = linear_fog_fade(vertexDistance, 8, 15);
        vertexColor = minecraft_mix_light(Light0_Direction, Light1_Direction, Normal, vec4(resultcol, resultcol, resultcol, 1)*(1-(Position.z-30.7)) * Color);
    }
    else{
        float resultcol = linear_fog_fade(vertexDistance, 8, 15);
        vertexColor = minecraft_mix_light(Light0_Direction, Light1_Direction, Normal, vec4(resultcol, resultcol, resultcol, 1) * Color);
    }
    lightMapColor = texelFetch(Sampler2, UV2 / 16, 0);
    overlayColor = texelFetch(Sampler1, UV1, 0);
    texCoord0 = UV0;
}
